@@ -2,14 +2,10 @@
 extern crate criterion;
 use criterion::{black_box, Criterion};
 
-use cairo;
-use cairo_sys;
-use rsvg_internals;
-
 use rsvg_internals::rect::IRect;
 use rsvg_internals::surface_utils::{
     iterators::Pixels,
-    shared_surface::{SharedImageSurface, SurfaceType},
+    shared_surface::{ExclusiveImageSurface, SharedImageSurface, SurfaceType},
 };
 
 const SURFACE_SIDE: i32 = 512;
@@ -23,9 +19,9 @@ const BOUNDS: IRect = IRect {
 fn bench_pixel_iterators(c: &mut Criterion) {
     c.bench_function("pixel_iterators straightforward", |b| {
         let mut surface =
-            cairo::ImageSurface::create(cairo::Format::ARgb32, SURFACE_SIDE, SURFACE_SIDE).unwrap();
-        let stride = surface.get_stride();
-        let data = surface.get_data().unwrap();
+            ExclusiveImageSurface::new(SURFACE_SIDE, SURFACE_SIDE, SurfaceType::SRgb).unwrap();
+        let stride = surface.stride() as i32;
+        let data = surface.get_data();
 
         let bounds = black_box(BOUNDS);
 
@@ -35,8 +31,8 @@ fn bench_pixel_iterators(c: &mut Criterion) {
             let mut b = 0usize;
             let mut a = 0usize;
 
-            for y in bounds.y0..bounds.y1 {
-                for x in bounds.x0..bounds.x1 {
+            for y in bounds.y_range() {
+                for x in bounds.x_range() {
                     let base = (y * stride + x * 4) as usize;
 
                     r += data[base + 0] as usize;
@@ -52,8 +48,7 @@ fn bench_pixel_iterators(c: &mut Criterion) {
 
     c.bench_function("pixel_iterators get_pixel", |b| {
         let surface =
-            cairo::ImageSurface::create(cairo::Format::ARgb32, SURFACE_SIDE, SURFACE_SIDE).unwrap();
-        let surface = SharedImageSurface::new(surface, SurfaceType::SRgb).unwrap();
+            SharedImageSurface::empty(SURFACE_SIDE, SURFACE_SIDE, SurfaceType::SRgb).unwrap();
 
         let bounds = black_box(BOUNDS);
 
@@ -63,8 +58,8 @@ fn bench_pixel_iterators(c: &mut Criterion) {
             let mut b = 0usize;
             let mut a = 0usize;
 
-            for y in bounds.y0..bounds.y1 {
-                for x in bounds.x0..bounds.x1 {
+            for y in bounds.y_range() {
+                for x in bounds.x_range() {
                     let pixel = surface.get_pixel(x as u32, y as u32);
 
                     r += pixel.r as usize;
@@ -80,8 +75,7 @@ fn bench_pixel_iterators(c: &mut Criterion) {
 
     c.bench_function("pixel_iterators pixels", |b| {
         let surface =
-            cairo::ImageSurface::create(cairo::Format::ARgb32, SURFACE_SIDE, SURFACE_SIDE).unwrap();
-        let data = SharedImageSurface::new(surface, SurfaceType::SRgb).unwrap();
+            SharedImageSurface::empty(SURFACE_SIDE, SURFACE_SIDE, SurfaceType::SRgb).unwrap();
 
         let bounds = black_box(BOUNDS);
 
@@ -91,7 +85,7 @@ fn bench_pixel_iterators(c: &mut Criterion) {
             let mut b = 0usize;
             let mut a = 0usize;
 
-            for (_x, _y, pixel) in Pixels::new(&data, bounds) {
+            for (_x, _y, pixel) in Pixels::within(&surface, bounds) {
                 r += pixel.r as usize;
                 g += pixel.g as usize;
                 b += pixel.b as usize;
