@@ -2,6 +2,7 @@ use cssparser::Parser;
 use markup5ever::{expanded_name, local_name, namespace_url, ns};
 use nalgebra::{Matrix3, Matrix4x5, Matrix5, Vector5};
 
+use crate::document::AcquiredNodes;
 use crate::drawing_ctx::DrawingCtx;
 use crate::error::*;
 use crate::node::{NodeResult, NodeTrait, RsvgNode};
@@ -48,6 +49,7 @@ impl Default for FeColorMatrix {
     }
 }
 
+#[rustfmt::skip]
 impl NodeTrait for FeColorMatrix {
     impl_node_as_filter_effect!();
 
@@ -67,7 +69,6 @@ impl NodeTrait for FeColorMatrix {
         // LuminanceToAlpha doesn't accept any matrix.
         if operation_type == OperationType::LuminanceToAlpha {
             self.matrix = {
-                #[cfg_attr(rustfmt, rustfmt_skip)]
                 Matrix5::new(
                     0.0,    0.0,    0.0,    0.0, 0.0,
                     0.0,    0.0,    0.0,    0.0, 0.0,
@@ -101,7 +102,6 @@ impl NodeTrait for FeColorMatrix {
                             }
                         })?;
 
-                        #[cfg_attr(rustfmt, rustfmt_skip)]
                         Matrix5::new(
                             0.213 + 0.787 * s, 0.715 - 0.715 * s, 0.072 - 0.072 * s, 0.0, 0.0,
                             0.213 - 0.213 * s, 0.715 + 0.285 * s, 0.072 - 0.072 * s, 0.0, 0.0,
@@ -114,21 +114,18 @@ impl NodeTrait for FeColorMatrix {
                         let degrees: f64 = attr.parse(value)?;
                         let (sin, cos) = degrees.to_radians().sin_cos();
 
-                        #[cfg_attr(rustfmt, rustfmt_skip)]
                         let a = Matrix3::new(
                             0.213, 0.715, 0.072,
                             0.213, 0.715, 0.072,
                             0.213, 0.715, 0.072,
                         );
 
-                        #[cfg_attr(rustfmt, rustfmt_skip)]
                         let b = Matrix3::new(
                              0.787, -0.715, -0.072,
                             -0.213,  0.285, -0.072,
                             -0.213, -0.715,  0.928,
                         );
 
-                        #[cfg_attr(rustfmt, rustfmt_skip)]
                         let c = Matrix3::new(
                             -0.213, -0.715,  0.928,
                              0.143,  0.140, -0.283,
@@ -157,9 +154,10 @@ impl FilterEffect for FeColorMatrix {
         &self,
         _node: &RsvgNode,
         ctx: &FilterContext,
+        acquired_nodes: &mut AcquiredNodes,
         draw_ctx: &mut DrawingCtx,
     ) -> Result<FilterResult, FilterError> {
-        let input = self.base.get_input(ctx, draw_ctx)?;
+        let input = self.base.get_input(ctx, acquired_nodes, draw_ctx)?;
         let bounds = self
             .base
             .get_bounds(ctx)
