@@ -4,6 +4,7 @@ use std::f64;
 
 use crate::bbox::BoundingBox;
 use crate::coord_units::CoordUnits;
+use crate::document::AcquiredNodes;
 use crate::drawing_ctx::{DrawingCtx, ViewParams};
 use crate::filter::Filter;
 use crate::node::RsvgNode;
@@ -13,6 +14,7 @@ use crate::rect::IRect;
 use crate::surface_utils::shared_surface::{
     ExclusiveImageSurface, SharedImageSurface, SurfaceType,
 };
+use crate::transform::Transform;
 use crate::unit_interval::UnitInterval;
 
 use super::error::FilterError;
@@ -86,12 +88,12 @@ pub struct FilterContext {
     /// This is to be used in conjunction with setting the viewbox size to account for the scaling.
     /// For `filterUnits == userSpaceOnUse`, the viewbox will have the actual resolution size, and
     /// for `filterUnits == objectBoundingBox`, the viewbox will have the size of 1, 1.
-    _affine: cairo::Matrix,
+    _affine: Transform,
 
     /// The filter primitive affine matrix.
     ///
     /// See the comments for `_affine`, they largely apply here.
-    paffine: cairo::Matrix,
+    paffine: Transform,
 }
 
 impl FilterContext {
@@ -103,7 +105,7 @@ impl FilterContext {
         draw_ctx: &mut DrawingCtx,
         node_bbox: BoundingBox,
     ) -> Self {
-        let cr_affine = draw_ctx.get_cairo_context().get_matrix();
+        let draw_transform = draw_ctx.get_transform();
 
         // The rect can be empty (for example, if the filter is applied to an empty group).
         // However, with userSpaceOnUse it's still possible to create images with a filter.
@@ -113,37 +115,32 @@ impl FilterContext {
         let filter = node_data.get_impl::<Filter>();
 
         let affine = match filter.get_filter_units() {
-            CoordUnits::UserSpaceOnUse => cr_affine,
-            CoordUnits::ObjectBoundingBox => {
-                let affine = cairo::Matrix::new(
-                    bbox_rect.width(),
-                    0.0,
-                    0.0,
-                    bbox_rect.height(),
-                    bbox_rect.x0,
-                    bbox_rect.y0,
-                );
-                cairo::Matrix::multiply(&affine, &cr_affine)
-            }
+            CoordUnits::UserSpaceOnUse => draw_transform,
+            CoordUnits::ObjectBoundingBox => Transform::new(
+                bbox_rect.width(),
+                0.0,
+                0.0,
+                bbox_rect.height(),
+                bbox_rect.x0,
+                bbox_rect.y0,
+            )
+            .post_transform(&draw_transform),
         };
 
         let paffine = match filter.get_primitive_units() {
-            CoordUnits::UserSpaceOnUse => cr_affine,
-            CoordUnits::ObjectBoundingBox => {
-                let affine = cairo::Matrix::new(
-                    bbox_rect.width(),
-                    0.0,
-                    0.0,
-                    bbox_rect.height(),
-                    bbox_rect.x0,
-                    bbox_rect.y0,
-                );
-                cairo::Matrix::multiply(&affine, &cr_affine)
-            }
+            CoordUnits::UserSpaceOnUse => draw_transform,
+            CoordUnits::ObjectBoundingBox => Transform::new(
+                bbox_rect.width(),
+                0.0,
+                0.0,
+                bbox_rect.height(),
+                bbox_rect.x0,
+                bbox_rect.y0,
+            )
+            .post_transform(&draw_transform),
         };
 
-        let width = source_surface.width();
-        let height = source_surface.height();
+        let (width, height) = (source_surface.width(), source_surface.height());
 
         Self {
             node: filter_node.clone(),
@@ -243,7 +240,7 @@ impl FilterContext {
 
     /// Returns the paffine matrix.
     #[inline]
-    pub fn paffine(&self) -> cairo::Matrix {
+    pub fn paffine(&self) -> Transform {
         self.paffine
     }
 
@@ -274,6 +271,7 @@ impl FilterContext {
     fn get_paint_server_surface(
         &self,
         draw_ctx: &mut DrawingCtx,
+        acquired_nodes: &mut AcquiredNodes,
         paint_server: &PaintServer,
         opacity: UnitInterval,
     ) -> Result<SharedImageSurface, cairo::Status> {
@@ -290,6 +288,7 @@ impl FilterContext {
             // FIXME: we are ignoring the following error; propagate it upstream
             let _ = draw_ctx
                 .set_source_paint_server(
+                    acquired_nodes,
                     paint_server,
                     opacity,
                     &self.node_bbox,
@@ -315,6 +314,7 @@ impl FilterContext {
     /// Does not take `processing_linear_rgb` into account.
     fn get_input_raw(
         &self,
+        acquired_nodes: &mut AcquiredNodes,
         draw_ctx: &mut DrawingCtx,
         in_: Option<&Input>,
     ) -> Result<FilterInput, FilterError> {
@@ -354,12 +354,22 @@ impl FilterContext {
                 .map(FilterInput::StandardInput),
 
             Input::FillPaint => self
-                .get_paint_server_surface(draw_ctx, &values.fill.0, values.fill_opacity.0)
+                .get_paint_server_surface(
+                    draw_ctx,
+                    acquired_nodes,
+                    &values.fill.0,
+                    values.fill_opacity.0,
+                )
                 .map_err(FilterError::CairoError)
                 .map(FilterInput::StandardInput),
 
             Input::StrokePaint => self
-                .get_paint_server_surface(draw_ctx, &values.stroke.0, values.stroke_opacity.0)
+                .get_paint_server_surface(
+                    draw_ctx,
+                    acquired_nodes,
+                    &values.stroke.0,
+                    values.stroke_opacity.0,
+                )
                 .map_err(FilterError::CairoError)
                 .map(FilterInput::StandardInput),
 
@@ -375,10 +385,11 @@ impl FilterContext {
     /// Retrieves the filter input surface according to the SVG rules.
     pub fn get_input(
         &self,
+        acquired_nodes: &mut AcquiredNodes,
         draw_ctx: &mut DrawingCtx,
         in_: Option<&Input>,
     ) -> Result<FilterInput, FilterError> {
-        let raw = self.get_input_raw(draw_ctx, in_)?;
+        let raw = self.get_input_raw(acquired_nodes, draw_ctx, in_)?;
 
         // Convert the input surface to the desired format.
         let (surface, bounds) = match raw {
