@@ -1,7 +1,7 @@
 use std::error::Error;
 use std::fmt;
 
-use cairo;
+use crate::error::RenderingError;
 
 /// An enumeration of errors that can occur during filter primitive rendering.
 #[derive(Debug, Clone, Copy, Eq, PartialEq)]
@@ -39,7 +39,7 @@ impl Error for FilterError {
     }
 
     #[inline]
-    fn cause(&self) -> Option<&Error> {
+    fn cause(&self) -> Option<&dyn Error> {
         None
     }
 }
@@ -62,3 +62,16 @@ impl From<cairo::Status> for FilterError {
         FilterError::CairoError(x)
     }
 }
+
+impl From<RenderingError> for FilterError {
+    #[inline]
+    fn from(e: RenderingError) -> Self {
+        if let RenderingError::Cairo(status) = e {
+            FilterError::CairoError(status)
+        } else {
+            // FIXME: this is just a dummy value; we should probably have a way to indicate
+            // an error in the underlying drawing process.
+            FilterError::CairoError(cairo::Status::InvalidStatus)
+        }
+    }
+}
