@@ -40,16 +40,11 @@
 #![warn(unused)]
 use ::xml as xml_rs;
 
-pub use crate::color::{rsvg_css_parse_color, ColorKind, ColorSpec};
+pub use crate::color::Color;
 
 pub use crate::dpi::{rsvg_rust_set_default_dpi_x_y, Dpi};
 
-pub use crate::drawing_ctx::RsvgRectangle;
-
-pub use crate::error::{
-    rsvg_rust_error_quark, set_gerror, DefsLookupErrorKind, HrefError, LoadingError,
-    RenderingError, RSVG_ERROR_FAILED,
-};
+pub use crate::error::{DefsLookupErrorKind, HrefError, LoadingError, RenderingError};
 
 pub use crate::handle::{
     Handle, LoadOptions, RsvgDimensionData, RsvgPositionData, RsvgSizeFunc, SizeCallback,
@@ -57,20 +52,25 @@ pub use crate::handle::{
 
 pub use crate::length::{Length, LengthUnit, RsvgLength};
 
+pub use crate::parsers::Parse;
+
 pub use crate::rect::IRect;
 
 pub use crate::structure::IntrinsicDimensions;
 
 pub use crate::surface_utils::{
     iterators::Pixels,
-    shared_surface::{
-        SharedImageSurface, SurfaceType,
-    },
+    shared_surface::{SharedImageSurface, SurfaceType},
 };
 
+pub use crate::viewbox::ViewBox;
+
 #[macro_use]
 pub mod log;
 
+#[macro_use]
+mod parsers;
+
 #[macro_use]
 mod coord_units;
 
@@ -84,11 +84,11 @@ mod allowed_url;
 mod angle;
 mod aspect_ratio;
 mod bbox;
-mod clip_path;
 mod color;
 mod cond;
 mod create_node;
 mod css;
+mod dasharray;
 mod document;
 mod dpi;
 mod drawing_ctx;
@@ -103,13 +103,10 @@ mod io;
 mod iri;
 mod length;
 mod limits;
-mod link;
 mod marker;
-mod mask;
 mod node;
 mod number_list;
 mod paint_server;
-mod parsers;
 mod path_builder;
 mod path_parser;
 mod pattern;
@@ -119,7 +116,6 @@ mod property_defs;
 pub mod rect;
 mod shapes;
 mod space;
-pub mod srgb;
 mod structure;
 mod style;
 pub mod surface_utils;
