@@ -10,6 +10,7 @@ use crate::allowed_url::Fragment;
 use crate::angle::Angle;
 use crate::aspect_ratio::*;
 use crate::bbox::BoundingBox;
+use crate::document::AcquiredNodes;
 use crate::drawing_ctx::DrawingCtx;
 use crate::error::*;
 use crate::float_eq_cairo::ApproxEqCairo;
@@ -21,6 +22,7 @@ use crate::path_builder::*;
 use crate::properties::{ComputedValues, SpecifiedValue, SpecifiedValues};
 use crate::property_bag::PropertyBag;
 use crate::rect::Rect;
+use crate::transform::Transform;
 use crate::viewbox::*;
 
 // markerUnits attribute: https://www.w3.org/TR/SVG/painting.html#MarkerElement
@@ -98,6 +100,7 @@ impl Marker {
     fn render(
         &self,
         node: &RsvgNode,
+        acquired_nodes: &mut AcquiredNodes,
         draw_ctx: &mut DrawingCtx,
         xpos: f64,
         ypos: f64,
@@ -119,54 +122,53 @@ impl Marker {
             return Ok(draw_ctx.empty_bbox());
         }
 
-        draw_ctx.with_saved_cr(&mut |dc| {
-            let cr = dc.get_cairo_context();
+        let rotation = match self.orient {
+            MarkerOrient::Auto => computed_angle,
+            MarkerOrient::Angle(a) => a,
+        };
 
-            cr.translate(xpos, ypos);
+        let mut transform = Transform::new_translate(xpos, ypos).pre_rotate(rotation);
 
-            let rotation = match self.orient {
-                MarkerOrient::Auto => computed_angle,
-                MarkerOrient::Angle(a) => a,
-            };
+        if self.units == MarkerUnits::StrokeWidth {
+            transform = transform.pre_scale(line_width, line_width);
+        }
 
-            cr.rotate(rotation.radians());
-
-            if self.units == MarkerUnits::StrokeWidth {
-                cr.scale(line_width, line_width);
+        let params = if let Some(vbox) = self.vbox {
+            if vbox.0.is_empty() {
+                return Ok(draw_ctx.empty_bbox());
             }
 
-            let params = if let Some(vbox) = self.vbox {
-                if vbox.0.is_empty() {
-                    return Ok(dc.empty_bbox());
-                }
+            let r = self
+                .aspect
+                .compute(&vbox, &Rect::from_size(marker_width, marker_height));
 
-                let r = self
-                    .aspect
-                    .compute(&vbox, &Rect::from_size(marker_width, marker_height));
+            let (vb_width, vb_height) = vbox.0.size();
+            transform = transform.pre_scale(r.width() / vb_width, r.height() / vb_height);
 
-                let (vb_width, vb_height) = vbox.0.size();
-                cr.scale(r.width() / vb_width, r.height() / vb_height);
+            draw_ctx.push_view_box(vb_width, vb_height)
+        } else {
+            draw_ctx.push_view_box(marker_width, marker_height)
+        };
 
-                dc.push_view_box(vb_width, vb_height)
-            } else {
-                dc.push_view_box(marker_width, marker_height)
-            };
+        transform = transform.pre_translate(
+            -self.ref_x.normalize(&values, &params),
+            -self.ref_y.normalize(&values, &params),
+        );
 
-            cr.translate(
-                -self.ref_x.normalize(&values, &params),
-                -self.ref_y.normalize(&values, &params),
-            );
+        let clip = if values.is_overflow() {
+            None
+        } else {
+            Some(
+                self.vbox
+                    .map_or_else(|| Rect::from_size(marker_width, marker_height), |vb| vb.0),
+            )
+        };
 
-            if !values.is_overflow() {
-                let clip_rect = self
-                    .vbox
-                    .map_or_else(|| Rect::from_size(marker_width, marker_height), |vb| vb.0);
-
-                dc.clip(clip_rect);
-            }
-
-            dc.with_discrete_layer(node, values, clipping, &mut |dc| {
-                node.draw_children(&cascaded, dc, clipping)
+        draw_ctx.with_saved_transform(Some(transform), &mut |dc| {
+            dc.with_clip_rect(clip, &mut |dc| {
+                dc.with_discrete_layer(node, acquired_nodes, values, clipping, &mut |an, dc| {
+                    node.draw_children(an, &cascaded, dc, clipping)
+                })
             })
         })
     }
@@ -560,6 +562,7 @@ enum MarkerType {
 
 fn emit_marker_by_name(
     draw_ctx: &mut DrawingCtx,
+    acquired_nodes: &mut AcquiredNodes,
     name: &Fragment,
     xpos: f64,
     ypos: f64,
@@ -567,11 +570,12 @@ fn emit_marker_by_name(
     line_width: f64,
     clipping: bool,
 ) -> Result<BoundingBox, RenderingError> {
-    if let Ok(acquired) = draw_ctx.acquire_node(name, &[NodeType::Marker]) {
+    if let Ok(acquired) = acquired_nodes.acquire(name, &[NodeType::Marker]) {
         let node = acquired.get();
 
         node.borrow().get_impl::<Marker>().render(
             &node,
+            acquired_nodes,
             draw_ctx,
             xpos,
             ypos,
@@ -616,6 +620,7 @@ where
 pub fn render_markers_for_path_builder(
     builder: &PathBuilder,
     draw_ctx: &mut DrawingCtx,
+    acquired_nodes: &mut AcquiredNodes,
     values: &ComputedValues,
     clipping: bool,
 ) -> Result<BoundingBox, RenderingError> {
@@ -645,7 +650,16 @@ pub fn render_markers_for_path_builder(
                 MarkerType::Middle => &values.marker_mid.0,
                 MarkerType::End => &values.marker_end.0,
             } {
-                emit_marker_by_name(draw_ctx, marker, x, y, computed_angle, line_width, clipping)
+                emit_marker_by_name(
+                    draw_ctx,
+                    acquired_nodes,
+                    marker,
+                    x,
+                    y,
+                    computed_angle,
+                    line_width,
+                    clipping,
+                )
             } else {
                 Ok(draw_ctx.empty_bbox())
             }
