@@ -22,6 +22,7 @@ use std::fmt;
 use crate::bbox::BoundingBox;
 use crate::cond::{RequiredExtensions, RequiredFeatures, SystemLanguage};
 use crate::css::Declaration;
+use crate::document::AcquiredNodes;
 use crate::drawing_ctx::DrawingCtx;
 use crate::error::*;
 use crate::filters::FilterEffect;
@@ -29,6 +30,7 @@ use crate::parsers::Parse;
 use crate::properties::{ComputedValues, SpecifiedValue, SpecifiedValues};
 use crate::property_bag::PropertyBag;
 use crate::property_defs::Overflow;
+use crate::transform::Transform;
 
 /// Strong reference to an element in the SVG tree.
 ///
@@ -49,7 +51,7 @@ pub struct NodeData {
     specified_values: SpecifiedValues,
     important_styles: HashSet<QualName>,
     result: NodeResult,
-    transform: cairo::Matrix,
+    transform: Transform,
     values: ComputedValues,
     cond: bool,
     style_attr: String,
@@ -71,7 +73,7 @@ impl NodeData {
             class: class.map(str::to_string),
             specified_values: Default::default(),
             important_styles: Default::default(),
-            transform: cairo::Matrix::identity(),
+            transform: Default::default(),
             result: Ok(()),
             values: ComputedValues::default(),
             cond: true,
@@ -112,7 +114,7 @@ impl NodeData {
         self.cond
     }
 
-    pub fn get_transform(&self) -> cairo::Matrix {
+    pub fn get_transform(&self) -> Transform {
         self.transform
     }
 
@@ -153,7 +155,7 @@ impl NodeData {
         for (attr, value) in pbag.iter() {
             match attr.expanded() {
                 expanded_name!("", "transform") => {
-                    return cairo::Matrix::parse_str(value)
+                    return Transform::parse_str(value)
                         .attribute(attr)
                         .and_then(|affine| {
                             self.transform = affine;
@@ -248,6 +250,7 @@ impl NodeData {
     }
 
     fn set_error(&mut self, error: NodeError) {
+        rsvg_log!("setting node {} in error: {}", self, error);
         self.result = Err(error);
     }
 
@@ -359,6 +362,7 @@ pub trait NodeTrait: Downcast {
     fn draw(
         &self,
         _node: &RsvgNode,
+        _acquired_nodes: &mut AcquiredNodes,
         _cascaded: &CascadedValues<'_>,
         draw_ctx: &mut DrawingCtx,
         _clipping: bool,
@@ -481,6 +485,7 @@ impl NodeCascade for RsvgNode {
 pub trait NodeDraw {
     fn draw(
         &self,
+        acquired_nodes: &mut AcquiredNodes,
         cascaded: &CascadedValues<'_>,
         draw_ctx: &mut DrawingCtx,
         clipping: bool,
@@ -488,6 +493,7 @@ pub trait NodeDraw {
 
     fn draw_children(
         &self,
+        acquired_nodes: &mut AcquiredNodes,
         cascaded: &CascadedValues<'_>,
         draw_ctx: &mut DrawingCtx,
         clipping: bool,
@@ -497,16 +503,17 @@ pub trait NodeDraw {
 impl NodeDraw for RsvgNode {
     fn draw(
         &self,
+        acquired_nodes: &mut AcquiredNodes,
         cascaded: &CascadedValues<'_>,
         draw_ctx: &mut DrawingCtx,
         clipping: bool,
     ) -> Result<BoundingBox, RenderingError> {
         if !self.borrow().is_in_error() {
             let transform = self.borrow().get_transform();
-            draw_ctx.with_saved_matrix(Some(transform), &mut |dc| {
+            draw_ctx.with_saved_transform(Some(transform), &mut |dc| {
                 self.borrow()
                     .get_node_trait()
-                    .draw(self, cascaded, dc, clipping)
+                    .draw(self, acquired_nodes, cascaded, dc, clipping)
             })
         } else {
             rsvg_log!("(not rendering element {} because it is in error)", self);
@@ -518,6 +525,7 @@ impl NodeDraw for RsvgNode {
 
     fn draw_children(
         &self,
+        acquired_nodes: &mut AcquiredNodes,
         cascaded: &CascadedValues<'_>,
         draw_ctx: &mut DrawingCtx,
         clipping: bool,
@@ -526,8 +534,9 @@ impl NodeDraw for RsvgNode {
 
         for child in self.children() {
             let child_bbox = draw_ctx.draw_node_from_stack(
-                &CascadedValues::new(cascaded, &child),
                 &child,
+                acquired_nodes,
+                &CascadedValues::new(cascaded, &child),
                 clipping,
             )?;
             bbox.insert(&child_bbox);
