@@ -226,7 +226,7 @@ pub struct ComputedValues {
     pub xml_space: XmlSpace, // not a property, but a non-presentation attribute
 }
 
-#[cfg_attr(rustfmt, rustfmt_skip)]
+#[rustfmt::skip]
 pub fn parse_property<'i>(prop_name: &QualName, input: &mut Parser<'i, '_>, accept_shorthands: bool) -> Result<ParsedProperty, ParseError<'i>> {
     // please keep these sorted
     match prop_name.expanded() {
@@ -405,7 +405,7 @@ macro_rules! compute_value {
 }
 
 impl SpecifiedValues {
-    #[cfg_attr(rustfmt, rustfmt_skip)]
+    #[rustfmt::skip]
     pub fn set_parsed_property(&mut self, prop: &ParsedProperty) {
         use crate::properties::ParsedProperty::*;
 
@@ -469,6 +469,13 @@ impl SpecifiedValues {
     }
 
     pub fn to_computed_values(&self, computed: &mut ComputedValues) {
+        // First, compute font.  It needs to be done before everything
+        // else, so that properties that depend on its computed value
+        // will be able to use it.  For example, baseline-shift
+        // depends on font-size.
+        compute_value!(self, computed, font_size);
+
+        // Then, do all the other properties.
         compute_value!(self, computed, baseline_shift);
         compute_value!(self, computed, clip_path);
         compute_value!(self, computed, clip_rule);
@@ -484,7 +491,6 @@ impl SpecifiedValues {
         compute_value!(self, computed, flood_color);
         compute_value!(self, computed, flood_opacity);
         compute_value!(self, computed, font_family);
-        compute_value!(self, computed, font_size);
         compute_value!(self, computed, font_stretch);
         compute_value!(self, computed, font_style);
         compute_value!(self, computed, font_variant);
