@@ -1,10 +1,10 @@
 //! Various utilities for working with Cairo image surfaces.
-use std::ops::DerefMut;
 
-use cairo;
+use std::ops::DerefMut;
 
 pub mod iterators;
 pub mod shared_surface;
+pub mod srgb;
 
 /// A pixel consisting of R, G, B and A values.
 #[derive(Debug, Clone, Copy, Eq, PartialEq, Hash)]
