@@ -1,12 +1,12 @@
 //! Text elements: `text`, `tspan`, `tref`.
 
-use glib::translate::*;
 use markup5ever::{expanded_name, local_name, namespace_url, ns};
 use pango::FontMapExt;
 use std::cell::RefCell;
 
 use crate::allowed_url::Fragment;
 use crate::bbox::BoundingBox;
+use crate::document::AcquiredNodes;
 use crate::drawing_ctx::DrawingCtx;
 use crate::error::*;
 use crate::float_eq_cairo::ApproxEqCairo;
@@ -22,6 +22,7 @@ use crate::property_defs::{
 };
 use crate::rect::Rect;
 use crate::space::{xml_space_normalize, NormalizeDefault, XmlSpaceNormalize};
+use crate::transform::Transform;
 
 /// An absolutely-positioned array of `Span`s
 ///
@@ -267,16 +268,15 @@ impl PositionedSpan {
 
     fn draw(
         &self,
+        acquired_nodes: &mut AcquiredNodes,
         draw_ctx: &mut DrawingCtx,
         clipping: bool,
     ) -> Result<BoundingBox, RenderingError> {
         draw_ctx.with_saved_cr(&mut |dc| {
-            let cr = dc.get_cairo_context();
-
-            let affine = cr.get_matrix();
+            let transform = dc.get_transform();
 
             let gravity = self.layout.get_context().unwrap().get_gravity();
-            let bbox = self.compute_text_bbox(affine, gravity);
+            let bbox = self.compute_text_bbox(transform, gravity);
             if bbox.is_none() {
                 return Ok(dc.empty_bbox());
             }
@@ -287,13 +287,12 @@ impl PositionedSpan {
                 bbox.unwrap()
             };
 
+            let cr = dc.get_cairo_context();
             cr.set_antialias(cairo::Antialias::from(self.values.text_rendering));
-
             dc.setup_cr_for_stroke(&cr, &self.values);
-
             cr.move_to(self.rendered_position.0, self.rendered_position.1);
 
-            let rotation = unsafe { pango_sys::pango_gravity_to_rotation(gravity.to_glib()) };
+            let rotation = gravity.to_rotation();
             if !rotation.approx_eq_cairo(0.0) {
                 cr.rotate(-rotation);
             }
@@ -302,6 +301,7 @@ impl PositionedSpan {
 
             let res = if !clipping {
                 dc.set_source_paint_server(
+                    acquired_nodes,
                     &self.values.fill.0,
                     self.values.fill_opacity.0,
                     &bbox,
@@ -323,6 +323,7 @@ impl PositionedSpan {
 
                 let res = if !clipping {
                     dc.set_source_paint_server(
+                        acquired_nodes,
                         &self.values.stroke.0,
                         self.values.stroke_opacity.0,
                         &bbox,
@@ -345,7 +346,9 @@ impl PositionedSpan {
                     if !clipping {
                         let (x0, y0, x1, y1) = cr.stroke_extents();
                         let r = Rect::new(x0, y0, x1, y1);
-                        let ib = BoundingBox::new().with_affine(affine).with_ink_rect(r);
+                        let ib = BoundingBox::new()
+                            .with_transform(transform)
+                            .with_ink_rect(r);
                         cr.stroke();
                         bbox.insert(&ib);
                     }
@@ -358,7 +361,7 @@ impl PositionedSpan {
 
     fn compute_text_bbox(
         &self,
-        affine: cairo::Matrix,
+        transform: Transform,
         gravity: pango::Gravity,
     ) -> Option<BoundingBox> {
         let (ink, _) = self.layout.get_extents();
@@ -391,7 +394,7 @@ impl PositionedSpan {
 
         let r = Rect::new(x, y, x + w, y + h);
         let bbox = BoundingBox::new()
-            .with_affine(affine)
+            .with_transform(transform)
             .with_rect(r)
             .with_ink_rect(r);
 
@@ -417,6 +420,7 @@ fn gravity_is_vertical(gravity: pango::Gravity) -> bool {
 fn children_to_chunks(
     chunks: &mut Vec<Chunk>,
     node: &RsvgNode,
+    acquired_nodes: &mut AcquiredNodes,
     cascaded: &CascadedValues<'_>,
     draw_ctx: &mut DrawingCtx,
     dx: Option<Length<Horizontal>>,
@@ -437,6 +441,7 @@ fn children_to_chunks(
                 let cascaded = CascadedValues::new(cascaded, &child);
                 child.borrow().get_impl::<TSpan>().to_chunks(
                     &child,
+                    acquired_nodes,
                     &cascaded,
                     draw_ctx,
                     chunks,
@@ -448,8 +453,8 @@ fn children_to_chunks(
                 let cascaded = CascadedValues::new(cascaded, &child);
                 child.borrow().get_impl::<TRef>().to_chunks(
                     &child,
+                    acquired_nodes,
                     &cascaded,
-                    draw_ctx,
                     chunks,
                     depth + 1,
                 );
@@ -581,12 +586,22 @@ impl Text {
     fn make_chunks(
         &self,
         node: &RsvgNode,
+        acquired_nodes: &mut AcquiredNodes,
         cascaded: &CascadedValues<'_>,
         draw_ctx: &mut DrawingCtx,
     ) -> Vec<Chunk> {
         let mut chunks = Vec::new();
         chunks.push(Chunk::new(cascaded.get(), Some(self.x), Some(self.y)));
-        children_to_chunks(&mut chunks, node, cascaded, draw_ctx, self.dx, self.dy, 0);
+        children_to_chunks(
+            &mut chunks,
+            node,
+            acquired_nodes,
+            cascaded,
+            draw_ctx,
+            self.dx,
+            self.dy,
+            0,
+        );
         chunks
     }
 }
@@ -609,6 +624,7 @@ impl NodeTrait for Text {
     fn draw(
         &self,
         node: &RsvgNode,
+        acquired_nodes: &mut AcquiredNodes,
         cascaded: &CascadedValues<'_>,
         draw_ctx: &mut DrawingCtx,
         clipping: bool,
@@ -619,7 +635,7 @@ impl NodeTrait for Text {
         let mut x = self.x.normalize(values, &params);
         let mut y = self.y.normalize(values, &params);
 
-        let chunks = self.make_chunks(node, cascaded, draw_ctx);
+        let chunks = self.make_chunks(node, acquired_nodes, cascaded, draw_ctx);
 
         let mut measured_chunks = Vec::new();
         for chunk in &chunks {
@@ -643,12 +659,12 @@ impl NodeTrait for Text {
             positioned_chunks.push(positioned);
         }
 
-        draw_ctx.with_discrete_layer(node, values, clipping, &mut |dc| {
+        draw_ctx.with_discrete_layer(node, acquired_nodes, values, clipping, &mut |an, dc| {
             let mut bbox = dc.empty_bbox();
 
             for chunk in &positioned_chunks {
                 for span in &chunk.spans {
-                    let span_bbox = span.draw(dc, clipping)?;
+                    let span_bbox = span.draw(an, dc, clipping)?;
                     bbox.insert(&span_bbox);
                 }
             }
@@ -667,8 +683,8 @@ impl TRef {
     fn to_chunks(
         &self,
         node: &RsvgNode,
+        acquired_nodes: &mut AcquiredNodes,
         cascaded: &CascadedValues<'_>,
-        draw_ctx: &mut DrawingCtx,
         chunks: &mut Vec<Chunk>,
         depth: usize,
     ) {
@@ -679,7 +695,7 @@ impl TRef {
         let link = self.link.as_ref().unwrap();
         let values = cascaded.get();
 
-        if let Ok(acquired) = draw_ctx.acquire_node(link, &[]) {
+        if let Ok(acquired) = acquired_nodes.acquire(link, &[]) {
             let c = acquired.get();
             extract_chars_children_to_chunks_recursively(chunks, &c, values, depth);
         } else {
@@ -736,18 +752,25 @@ impl TSpan {
     fn to_chunks(
         &self,
         node: &RsvgNode,
+        acquired_nodes: &mut AcquiredNodes,
         cascaded: &CascadedValues<'_>,
         draw_ctx: &mut DrawingCtx,
         chunks: &mut Vec<Chunk>,
         depth: usize,
     ) {
-        if self.x.is_some() || self.y.is_some() {
-            // Any absolute position creates a new chunk
-            let values = cascaded.get();
-            chunks.push(Chunk::new(values, self.x, self.y));
-        }
+        let values = cascaded.get();
+        chunks.push(Chunk::new(values, self.x, self.y));
 
-        children_to_chunks(chunks, node, cascaded, draw_ctx, self.dx, self.dy, depth);
+        children_to_chunks(
+            chunks,
+            node,
+            acquired_nodes,
+            cascaded,
+            draw_ctx,
+            self.dx,
+            self.dy,
+            depth,
+        );
     }
 }
 
